@@ -6,7 +6,7 @@ import logging
 log = logging.getLogger("Thug")
 
 
-def Upgrade(self, arg0, arg1, arg2, arg3):
+def Upgrade(self, arg0, arg1, arg2, arg3): # pylint:disable=unused-argument
     if len(arg0) > 6000:
         log.ThugLogging.log_exploit_event(self._window.url,
                                           "Move Networks Upgrade Manager ActiveX",
