@@ -6,10 +6,10 @@ import logging
 log = logging.getLogger("Thug")
 
 
-def CreateObject(self, _object, param = ''):
-    import thug.ActiveX as ActiveX
+def CreateObject(self, _object, param = ''): # pylint:disable=unused-argument
+    from thug import ActiveX
 
-    log.ThugLogging.add_behavior_warn("[Microsoft MDAC RDS.Dataspace ActiveX] CreateObject (%s)" % (_object))
+    log.ThugLogging.add_behavior_warn(f"[Microsoft MDAC RDS.Dataspace ActiveX] CreateObject ({_object})")
     log.ThugLogging.log_exploit_event(self._window.url,
                                       "Microsoft MDAC RDS.Dataspace ActiveX",
                                       "CreateObject",
