@@ -6,8 +6,8 @@ import logging
 log = logging.getLogger("Thug")
 
 
-def RemoveFileOrDir(self, arg0, arg1):
-    log.ThugLogging.add_behavior_warn('[Universal HTTP File Upload ActiveX] Deleting %s' % (arg0, ))
+def RemoveFileOrDir(self, arg0, arg1): # pylint:disable=unused-argument
+    log.ThugLogging.add_behavior_warn(f'[Universal HTTP File Upload ActiveX] Deleting {arg0}')
     log.ThugLogging.log_exploit_event(self._window.url,
                                       "Universal HTTP File Upload ActiveX",
                                       "Deleting",
