@@ -4,5 +4,5 @@ import logging
 log = logging.getLogger("Thug")
 
 
-def openPlayer(self, arg):
+def openPlayer(self, arg): # pylint:disable=unused-argument
     log.warning(arg)
