@@ -18,11 +18,13 @@
 
 
 import os
+import io
+import types
+import operator
 import json
 import logging
 import zipfile
 import tempfile
-import six
 import bs4
 import rarfile
 
@@ -233,7 +235,7 @@ class MIMEHandler(dict):
         for mimetype in self.mimetypes:
             self[mimetype] = self.passthrough
 
-        self.handlers = list()
+        self.handlers = []
 
         self.register_empty_handlers()
         self.register_fallback_handlers()
@@ -250,10 +252,13 @@ class MIMEHandler(dict):
         if hooks is None:
             return
 
+        get_method_function = operator.attrgetter("__func__")
+        get_method_self = operator.attrgetter("__self__")
+
         for label, hook in hooks.items():
-            name   = "{}_hook".format(label)
-            _hook = six.get_method_function(hook) if six.get_method_self(hook) else hook
-            method = six.create_bound_method(_hook, MIMEHandler)
+            name   = f"{label}_hook"
+            _hook = get_method_function(hook) if get_method_self(hook) else hook
+            method = types.MethodType(_hook, MIMEHandler)
             setattr(self, name, method)
 
         hook = getattr(self, "handle_image_hook", None)
@@ -268,7 +273,8 @@ class MIMEHandler(dict):
         self['text/javascript']          = None
 
     def register_fallback_handlers(self):
-        self['text/plain'] = self.handle_fallback
+        self['text/plain']               = self.handle_fallback
+        self['application/octet-stream'] = self.handle_fallback
 
     def register_handler(self, mimetype, handler):
         self[mimetype] = handler
@@ -302,7 +308,7 @@ class MIMEHandler(dict):
             try:
                 if handler(url, content):
                     return True
-            except Exception: # pragma: no cover
+            except Exception: # pragma: no cover,pylint:disable=broad-except
                 pass
 
         return False
@@ -332,7 +338,7 @@ class MIMEHandler(dict):
             if ocr_result:
                 log.ThugLogging.log_image_ocr(url, ocr_result)
                 log.ImageClassifier.classify(url, ocr_result)
-        except Exception as e: # pragma: no cover
+        except Exception as e: # pragma: no cover,pylint:disable=broad-except
             log.warning("[OCR] Error: %s", str(e))
             return False
 
@@ -340,9 +346,9 @@ class MIMEHandler(dict):
 
     def perform_ocr_analysis(self, url, content):
         try:
-            fp  = six.BytesIO(content)
+            fp  = io.BytesIO(content)
             img = Image.open(fp)
-        except Exception as e: # pragma: no cover
+        except Exception as e: # pragma: no cover,pylint:disable=broad-except
             log.warning("[OCR] Error: %s", str(e))
             return
 
@@ -353,13 +359,13 @@ class MIMEHandler(dict):
         if len(content) < self.MIN_ZIP_FILE_SIZE: # pragma: no cover
             return False
 
-        fp = six.BytesIO(content)
+        fp = io.BytesIO(content)
         if not zipfile.is_zipfile(fp):
             return False
 
         try:
             zipdata = zipfile.ZipFile(fp)
-        except Exception as e: # pragma: no cover
+        except Exception as e: # pragma: no cover,pylint:disable=broad-except
             log.warning("[MIMEHANDLER (ZIP)][ERROR] %s", str(e))
             return False
 
@@ -370,7 +376,7 @@ class MIMEHandler(dict):
 
             try:
                 data = zipdata.read(filename)
-            except Exception as e: # pragma: no cover
+            except Exception as e: # pragma: no cover,pylint:disable=broad-except
                 log.warning("[MIMEHANDLER (ZIP)][ERROR] %s", str(e))
                 continue
 
@@ -384,7 +390,7 @@ class MIMEHandler(dict):
                     try:
                         with window.context as ctxt:
                             ctxt.eval(data)
-                    except Exception as e: # pragma: no cover
+                    except Exception as e: # pragma: no cover,pylint:disable=broad-except
                         log.warning("[MIMEHANDLER (ZIP)][ERROR] %s", str(e))
 
                 sample = log.ThugLogging.log_file(data, url, sampletype = 'JS')
@@ -397,7 +403,7 @@ class MIMEHandler(dict):
 
             try:
                 md5 = sample['md5']
-            except Exception as e: # pragma: no cover
+            except Exception as e: # pragma: no cover,pylint:disable=broad-except
                 log.warning("[MIMEHANDLER (ZIP)][ERROR] %s", str(e))
                 continue
 
@@ -416,7 +422,7 @@ class MIMEHandler(dict):
 
         try:
             rardata = rarfile.RarFile(rfile)
-        except Exception as e:
+        except Exception as e: # pylint:disable=broad-except
             log.warning("[MIMEHANDLER (RAR)][ERROR] %s", str(e))
             os.remove(rfile)
             return False
@@ -426,7 +432,7 @@ class MIMEHandler(dict):
         for filename in rardata.namelist():
             try:
                 data = rardata.read(filename)
-            except Exception as e: # pragma: no cover
+            except Exception as e: # pragma: no cover,pylint:disable=broad-except
                 log.warning("[MIMEHANDLER (RAR)][ERROR] %s", str(e))
                 continue
 
@@ -439,7 +445,7 @@ class MIMEHandler(dict):
 
             try:
                 md5 = sample['md5']
-            except Exception as e: # pragma: no cover
+            except Exception as e: # pragma: no cover,pylint:disable=broad-except
                 log.warning("[MIMEHANDLER (RAR)][ERROR] %s", str(e))
                 continue
 
@@ -453,16 +459,16 @@ class MIMEHandler(dict):
     def javaWebStartUserAgent(self):
         javaplugin = log.ThugVulnModules._javaplugin.split('.')
         last = javaplugin.pop()
-        version = '%s_%s' % ('.'.join(javaplugin), last)
-        return "JNLP/6.0 javaws/%s (b04) Java/%s" % (version, version, )
+        version = f"{'.'.join(javaplugin)}_{last}"
+        return f"JNLP/6.0 javaws/{version} (b04) Java/{version}"
 
     def handle_java_jnlp(self, url, data):
-        headers = dict()
+        headers = {}
         headers['Connection'] = 'keep-alive'
 
         try:
             soup = bs4.BeautifulSoup(data, "lxml")
-        except Exception: # pragma: no cover
+        except Exception: # pragma: no cover,pylint:disable=broad-except
             return
 
         jnlp = soup.find("jnlp")
@@ -481,33 +487,33 @@ class MIMEHandler(dict):
 
         for jar in jars:
             try:
-                url = "%s%s" % (codebase, jar.attrs['href'], )
+                url = f"{codebase}{jar.attrs['href']}"
                 log.DFT.window._navigator.fetch(url, headers = headers, redirect_type = "JNLP")
-            except Exception: # pragma: no cover
+            except Exception: # pragma: no cover,pylint:disable=broad-except
                 pass
 
-    def handle_json(self, url, data):
+    def handle_json(self, url, data): # pylint:disable=unused-argument
         try:
             content = json.loads(data)
-        except Exception: # pragma: no cover
+        except Exception: # pragma: no cover,pylint:disable=broad-except
             return False
 
         if not isinstance(content, dict): # pragma: no cover
             return False
 
-        headers = dict()
+        headers = {}
         headers['Connection'] = 'keep-alive'
 
         for key in content.keys():
             if key.lower() in ('@content.downloadurl', ):
                 try:
                     log.DFT.window._navigator.fetch(content[key], headers = headers, redirect_type = "JSON")
-                except Exception:
+                except Exception: # pylint:disable=broad-except
                     pass
 
         return True
 
-    def passthrough(self, url, data):
+    def passthrough(self, url, data): # pylint:disable=unused-argument
         """
         The method passthrough is the default handler associated to
         almost all Content-Types with the few exceptions defined in
