@@ -10,6 +10,10 @@ this.console = window.console;
 window = this;
 window.top = this;
 
+Document.prototype = window.document;
+HTMLElement.prototype = window.document.createElement("p");
+XMLHttpRequest.prototype = new XMLHttpRequest;
+
 Object.defineProperty(window, "location", {
 	set: function(value){
 		window.setLocation(value);
